# redrover-api
Access Red Rover data via this REST API for Organizations that have granted you access.

# Authentication
The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.

This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.

Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.

# API Information
## Api Key
Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.

You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.

## Identifier
Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pike character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pike character.

## Transaction Id
Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.12.2
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/edustaff/redrover-api.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/edustaff/redrover-api.git`)

Then import the package:
```python
import redrover_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import redrover_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import redrover_api
from redrover_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = redrover_api.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basic
configuration = redrover_api.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)


# Enter a context with an instance of the API client
with redrover_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = redrover_api.AbsenceApi(api_client)
    org_id = 56 # int | The Red Rover Id of the Organization
    absence_create_request = redrover_api.AbsenceCreateRequest() # AbsenceCreateRequest | The details of the Absence

    try:
        # Create new Absence
        api_response = api_instance.create_absence(org_id, absence_create_request)
        print("The response of AbsenceApi->create_absence:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AbsenceApi->create_absence: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AbsenceApi* | [**create_absence**](docs/AbsenceApi.md#create_absence) | **POST** /api/v1/{orgId}/Absence | Create new Absence
*AbsenceApi* | [**delete_absence**](docs/AbsenceApi.md#delete_absence) | **DELETE** /api/v1/{orgId}/Absence/{identifier} | Delete an Absence
*AbsenceApi* | [**get_absence**](docs/AbsenceApi.md#get_absence) | **GET** /api/v1/{orgId}/Absence/{identifier} | Get Absence
*AbsenceApi* | [**get_absences**](docs/AbsenceApi.md#get_absences) | **GET** /api/v1/{orgId}/Absence | Get list of Absences
*AbsenceApi* | [**update_absence**](docs/AbsenceApi.md#update_absence) | **PUT** /api/v1/{orgId}/Absence/{identifier} | Update existing Absence
*AbsenceReasonApi* | [**get_absence_reason**](docs/AbsenceReasonApi.md#get_absence_reason) | **GET** /api/v1/{orgId}/AbsenceReason/{identifier} | Get Absence Reason
*AbsenceReasonApi* | [**get_absence_reasons**](docs/AbsenceReasonApi.md#get_absence_reasons) | **GET** /api/v1/{orgId}/AbsenceReason | Get list of Absence Reasons
*AbsenceReasonBalanceApi* | [**create_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#create_absence_reason_balance) | **POST** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances | Create Absence Reason Balance
*AbsenceReasonBalanceApi* | [**delete_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#delete_absence_reason_balance) | **DELETE** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Delete Absence Reason Balance
*AbsenceReasonBalanceApi* | [**get_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#get_absence_reason_balance) | **GET** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Get Absence Reason Balance
*AbsenceReasonBalanceApi* | [**get_absence_reason_balances**](docs/AbsenceReasonBalanceApi.md#get_absence_reason_balances) | **GET** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances | Get Absence Reason Balances
*AbsenceReasonBalanceApi* | [**update_absence_reason_balance**](docs/AbsenceReasonBalanceApi.md#update_absence_reason_balance) | **PUT** /api/v1/{orgId}/Employee/{employeeIdentifier}/absenceReasonBalances/{id} | Update Absence Reason Balance
*AssignmentApi* | [**get_assignment**](docs/AssignmentApi.md#get_assignment) | **GET** /api/v1/{orgId}/Assignment/{identifier} | Get Assignment
*AttributeApi* | [**create_attributes**](docs/AttributeApi.md#create_attributes) | **POST** /api/v1/{orgId}/ReferenceData/attribute | Create attribute
*AttributeApi* | [**gets_attributes**](docs/AttributeApi.md#gets_attributes) | **GET** /api/v1/{orgId}/ReferenceData/attribute | Get Attributes
*ConnectionApi* | [**download_report**](docs/ConnectionApi.md#download_report) | **GET** /api/v1/{orgId}/Connection/{id}/download | Download Report
*ConnectionApi* | [**download_report_0**](docs/ConnectionApi.md#download_report_0) | **POST** /api/v1/{orgId}/Connection/{id}/download | Download Report
*ConnectionApi* | [**post_report_data**](docs/ConnectionApi.md#post_report_data) | **POST** /api/v1/{orgId}/Connection/{id}/data | Posts Report
*ConnectionApi* | [**run_report**](docs/ConnectionApi.md#run_report) | **POST** /api/v1/{orgId}/Connection/{id}/run | Run Report
*OrganizationApi* | [**get_current_school_years**](docs/OrganizationApi.md#get_current_school_years) | **GET** /api/v1/Organization/{id}/schoolYear/current | Get current School Year
*OrganizationApi* | [**get_organization**](docs/OrganizationApi.md#get_organization) | **GET** /api/v1/Organization/{id} | Get Organization
*OrganizationApi* | [**get_organizations**](docs/OrganizationApi.md#get_organizations) | **GET** /api/v1/Organization | Get Organizations
*OrganizationApi* | [**get_school_years**](docs/OrganizationApi.md#get_school_years) | **GET** /api/v1/Organization/{id}/schoolYear | Get School Years
*PayCodeApi* | [**create_pay_code**](docs/PayCodeApi.md#create_pay_code) | **POST** /api/v1/{orgId}/PayCode | Create new pay code
*PayCodeApi* | [**delete_pay_code**](docs/PayCodeApi.md#delete_pay_code) | **DELETE** /api/v1/{orgId}/PayCode/{identifier} | Delete an pay code
*PayCodeApi* | [**get_pay_code**](docs/PayCodeApi.md#get_pay_code) | **GET** /api/v1/{orgId}/PayCode/{identifier} | Get PayCode
*PayCodeApi* | [**get_pay_codes**](docs/PayCodeApi.md#get_pay_codes) | **GET** /api/v1/{orgId}/PayCode | Get all pay codes
*PayCodeApi* | [**update_pay_code**](docs/PayCodeApi.md#update_pay_code) | **PUT** /api/v1/{orgId}/PayCode/{identifier} | Update existing pay code
*UserApi* | [**create_admin**](docs/UserApi.md#create_admin) | **POST** /api/v1/{orgId}/User/administrator | Creates Administrator
*UserApi* | [**create_employee**](docs/UserApi.md#create_employee) | **POST** /api/v1/{orgId}/User/employee | Creates Employee
*UserApi* | [**create_substitute**](docs/UserApi.md#create_substitute) | **POST** /api/v1/{orgId}/User/substitute | Creates Substitute
*UserApi* | [**delete_user**](docs/UserApi.md#delete_user) | **DELETE** /api/v1/{orgId}/User/{identifier} | Deletes User
*UserApi* | [**delete_user_role**](docs/UserApi.md#delete_user_role) | **DELETE** /api/v1/{orgId}/User/{identifier}/{role} | Deletes User&#39;s Role
*UserApi* | [**get_admin**](docs/UserApi.md#get_admin) | **GET** /api/v1/{orgId}/User/administrator/{identifier} | Gets Administrator
*UserApi* | [**get_employee**](docs/UserApi.md#get_employee) | **GET** /api/v1/{orgId}/User/employee/{identifier} | Gets Employee
*UserApi* | [**get_substitute**](docs/UserApi.md#get_substitute) | **GET** /api/v1/{orgId}/User/substitute/{identifier} | Get Substitute by Id
*UserApi* | [**get_substitutes**](docs/UserApi.md#get_substitutes) | **GET** /api/v1/{orgId}/User/substitute | Query for Substitutes
*UserApi* | [**update_admin**](docs/UserApi.md#update_admin) | **PUT** /api/v1/{orgId}/User/administrator/{identifier} | Updates Administrator
*UserApi* | [**update_employee**](docs/UserApi.md#update_employee) | **PUT** /api/v1/{orgId}/User/employee/{identifier} | Updates Employee
*UserApi* | [**update_substitute**](docs/UserApi.md#update_substitute) | **PUT** /api/v1/{orgId}/User/substitute/{identifier} | Updates Substitute
*VacancyApi* | [**delete_vacancy**](docs/VacancyApi.md#delete_vacancy) | **DELETE** /api/v1/{orgId}/Vacancy/{identifier} | Delete Vacancy By Id
*VacancyApi* | [**get_vacancy**](docs/VacancyApi.md#get_vacancy) | **GET** /api/v1/{orgId}/Vacancy/{identifier} | Get Vacancy By Id
*VacancyApi* | [**get_vacancy_details**](docs/VacancyApi.md#get_vacancy_details) | **GET** /api/v1/{orgId}/Vacancy/vacancyDetails |  Query Vacancy Details
*VacancyApi* | [**post_vacancy**](docs/VacancyApi.md#post_vacancy) | **POST** /api/v1/{orgId}/Vacancy | Create a Vacancy
*WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /api/v1/Webhooks | Create Webhook.
*WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /api/v1/Webhooks/{id} | Delete Webhook
*WebhooksApi* | [**get_webhook**](docs/WebhooksApi.md#get_webhook) | **GET** /api/v1/Webhooks | Get Webhooks
*WebhooksApi* | [**get_webhook_0**](docs/WebhooksApi.md#get_webhook_0) | **GET** /api/v1/Webhooks/{identifier} | Get Webhook
*WebhooksApi* | [**put_webhook_uri**](docs/WebhooksApi.md#put_webhook_uri) | **PUT** /api/v1/Webhooks/{id} | Update Webhook


## Documentation For Models

 - [AbsenceCreateRequest](docs/AbsenceCreateRequest.md)
 - [AbsenceDetailCreateRequest](docs/AbsenceDetailCreateRequest.md)
 - [AbsenceDetailResponse](docs/AbsenceDetailResponse.md)
 - [AbsenceReasonBalanceCreateRequest](docs/AbsenceReasonBalanceCreateRequest.md)
 - [AbsenceReasonBalanceResponse](docs/AbsenceReasonBalanceResponse.md)
 - [AbsenceReasonBalanceUpdateRequest](docs/AbsenceReasonBalanceUpdateRequest.md)
 - [AbsenceReasonCategoryResponse](docs/AbsenceReasonCategoryResponse.md)
 - [AbsenceReasonResponse](docs/AbsenceReasonResponse.md)
 - [AbsenceReasonTrackingTypeEnum](docs/AbsenceReasonTrackingTypeEnum.md)
 - [AbsenceReasonUsageCreateRequest](docs/AbsenceReasonUsageCreateRequest.md)
 - [AbsenceReasonUsageResponse](docs/AbsenceReasonUsageResponse.md)
 - [AbsenceResponse](docs/AbsenceResponse.md)
 - [AbsenceUpdateRequest](docs/AbsenceUpdateRequest.md)
 - [AbsenceVacancyDetailRequest](docs/AbsenceVacancyDetailRequest.md)
 - [AbsenceVacancyRequest](docs/AbsenceVacancyRequest.md)
 - [AccessControlRequest](docs/AccessControlRequest.md)
 - [AccessControlResponse](docs/AccessControlResponse.md)
 - [AccountingCodeAllocationRequest](docs/AccountingCodeAllocationRequest.md)
 - [AccountingCodeAllocationResponse](docs/AccountingCodeAllocationResponse.md)
 - [AccountingCodeLightResponse](docs/AccountingCodeLightResponse.md)
 - [AdministratorRequest](docs/AdministratorRequest.md)
 - [AdministratorResponse](docs/AdministratorResponse.md)
 - [ApprovalStatusEnum](docs/ApprovalStatusEnum.md)
 - [AssignmentResponse](docs/AssignmentResponse.md)
 - [AttributeRequest](docs/AttributeRequest.md)
 - [AttributeResponse](docs/AttributeResponse.md)
 - [AuthenticationProperties](docs/AuthenticationProperties.md)
 - [BadRequestResult](docs/BadRequestResult.md)
 - [ContractLightResponse](docs/ContractLightResponse.md)
 - [CountryEnum](docs/CountryEnum.md)
 - [DayOfWeek](docs/DayOfWeek.md)
 - [DayPartEnum](docs/DayPartEnum.md)
 - [EmployeeRequest](docs/EmployeeRequest.md)
 - [EmployeeResponse](docs/EmployeeResponse.md)
 - [FileFormat](docs/FileFormat.md)
 - [FillStatusEnum](docs/FillStatusEnum.md)
 - [ForbidResult](docs/ForbidResult.md)
 - [Int32IdNameClass](docs/Int32IdNameClass.md)
 - [Int32LocatorRequest](docs/Int32LocatorRequest.md)
 - [Int32LocatorResponse](docs/Int32LocatorResponse.md)
 - [NotFoundResult](docs/NotFoundResult.md)
 - [OkObjectResult](docs/OkObjectResult.md)
 - [OkResult](docs/OkResult.md)
 - [OrgUserEmployeeResponse](docs/OrgUserEmployeeResponse.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [PayCodeCreateRequest](docs/PayCodeCreateRequest.md)
 - [PayCodeResponse](docs/PayCodeResponse.md)
 - [PayCodeUpdateRequest](docs/PayCodeUpdateRequest.md)
 - [PositionJobRequest](docs/PositionJobRequest.md)
 - [PositionRequest](docs/PositionRequest.md)
 - [PositionResponse](docs/PositionResponse.md)
 - [PositionScheduleCustomVariantRequest](docs/PositionScheduleCustomVariantRequest.md)
 - [PositionScheduleItemRequest](docs/PositionScheduleItemRequest.md)
 - [PositionScheduleModeEnum](docs/PositionScheduleModeEnum.md)
 - [PositionScheduleRequest](docs/PositionScheduleRequest.md)
 - [Reason](docs/Reason.md)
 - [SchoolYearResponse](docs/SchoolYearResponse.md)
 - [SimpleAbsenceDetail](docs/SimpleAbsenceDetail.md)
 - [SimplePerson](docs/SimplePerson.md)
 - [SimplePosition](docs/SimplePosition.md)
 - [SimplePositionResponse](docs/SimplePositionResponse.md)
 - [StateEnum](docs/StateEnum.md)
 - [SubstituteAttributeRequest](docs/SubstituteAttributeRequest.md)
 - [SubstituteAttributeResponse](docs/SubstituteAttributeResponse.md)
 - [SubstitutePreferencesRequest](docs/SubstitutePreferencesRequest.md)
 - [SubstituteRelatedOrgRequest](docs/SubstituteRelatedOrgRequest.md)
 - [SubstituteRequest](docs/SubstituteRequest.md)
 - [SubstituteResponse](docs/SubstituteResponse.md)
 - [TimeOffBalanceRequest](docs/TimeOffBalanceRequest.md)
 - [UserRoles](docs/UserRoles.md)
 - [VacancyAccountingCodeAllocationRequest](docs/VacancyAccountingCodeAllocationRequest.md)
 - [VacancyCreateRequest](docs/VacancyCreateRequest.md)
 - [VacancyDetailCreateRequest](docs/VacancyDetailCreateRequest.md)
 - [VacancyDetailResponse](docs/VacancyDetailResponse.md)
 - [VacancyDetailSearchResponse](docs/VacancyDetailSearchResponse.md)
 - [VacancyResponse](docs/VacancyResponse.md)
 - [WebhookCreateRequest](docs/WebhookCreateRequest.md)
 - [WebhookResponse](docs/WebhookResponse.md)
 - [WebhookUpdateRequest](docs/WebhookUpdateRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basic"></a>
### basic

- **Type**: HTTP basic authentication

<a id="apiKey"></a>
### apiKey

- **Type**: HTTP basic authentication


## Author

dev@redroverk12.com


